pub struct SendTakeInstructionArgs {
pub side: Side,
pub limit_price: u64,
pub max_coin_qty: u64,
pub max_native_pc_qty_including_fees: u64,
pub min_coin_qty: u64,
pub min_native_pc_qty: u64,
pub limit: u16,
}Fields
side: Sidelimit_price: u64max_coin_qty: u64max_native_pc_qty_including_fees: u64min_coin_qty: u64min_native_pc_qty: u64limit: u16Trait Implementations
Sourceimpl BorshDeserialize for SendTakeInstructionArgs
impl BorshDeserialize for SendTakeInstructionArgs
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for SendTakeInstructionArgs
impl Clone for SendTakeInstructionArgs
Sourcefn clone(&self) -> SendTakeInstructionArgs
fn clone(&self) -> SendTakeInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SendTakeInstructionArgs
impl Debug for SendTakeInstructionArgs
impl Eq for SendTakeInstructionArgs
Sourceimpl PartialEq for SendTakeInstructionArgs
impl PartialEq for SendTakeInstructionArgs
Sourcefn eq(&self, other: &SendTakeInstructionArgs) -> bool
fn eq(&self, other: &SendTakeInstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for SendTakeInstructionArgs